Index: /code/branches/objecthierarchy/src/orxonox/CMakeLists.txt
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/CMakeLists.txt	(revision 2072)
+++ /code/branches/objecthierarchy/src/orxonox/CMakeLists.txt	(revision 2073)
@@ -1,4 +1,4 @@
 SET( ORXONOX_SRC_FILES
-  CameraHandler.cc
+  CameraManager.cc
   GraphicsEngine.cc
   LevelManager.cc
@@ -106,5 +106,5 @@
     GraphicsEngine.cc
     objects/Camera.cc
-    objects/CameraHandler.cc
+    CameraManager.cc
   )
 
Index: de/branches/objecthierarchy/src/orxonox/CameraHandler.cc
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/CameraHandler.cc	(revision 2072)
+++ 	(revision )
@@ -1,103 +1,0 @@
-/*
- *   ORXONOX - the hottest 3D action shooter ever to exist
- *                    > www.orxonox.net <
- *
- *
- *   License notice:
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License
- *   as published by the Free Software Foundation; either version 2
- *   of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- *   Author:
- *      Benjamin Knecht
- *   Co-authors:
- *      ...
- *
- */
-#include "OrxonoxStableHeaders.h"
-#include "CameraHandler.h"
-
-#include <OgreViewport.h>
-
-#include "core/Core.h"
-#include "objects/worldentities/Camera.h"
-
-
-namespace orxonox
-{
-    CameraHandler* CameraHandler::singletonRef_s = 0;
-
-    CameraHandler::CameraHandler(Ogre::Viewport* viewport)
-        : viewport_(viewport)
-    {
-        assert(singletonRef_s == 0);
-        singletonRef_s = this;
-    }
-
-    CameraHandler::~CameraHandler()
-    {
-        assert(singletonRef_s != 0);
-        singletonRef_s = 0;
-    }
-
-    Camera* CameraHandler::getActiveCamera() const
-    {
-        if (this->cameraList_.size() > 0)
-            return this->cameraList_.front();
-        else
-            return 0;
-    }
-
-    void CameraHandler::requestFocus(Camera* camera)
-    {
-        if (!Core::showsGraphics())
-            return;
-
-        // notify old camera (if it exists)
-        if (this->cameraList_.size() > 0)
-            this->cameraList_.front()->removeFocus();
-
-        camera->setFocus(this->viewport_);
-
-        // add to list
-        std::list<Camera*>::iterator it;
-        for (it = this->cameraList_.begin(); it != this->cameraList_.end(); ++it)
-        {
-            if ((*it) == camera)
-                return; // make sure we don't add it twice
-        }
-        this->cameraList_.push_front(camera);
-    }
-
-    void CameraHandler::releaseFocus(Camera* camera)
-    {
-        if (!Core::showsGraphics())
-            return;
-
-        // notify the cam of releasing the focus
-        if (this->cameraList_.front() == camera)
-        {
-            camera->removeFocus();
-            this->cameraList_.pop_front();
-
-            // set new focus if necessary
-            if (cameraList_.size() > 0)
-                cameraList_.front()->setFocus(this->viewport_);
-        }
-        else
-        {
-            this->cameraList_.remove(camera);
-        }
-    }
-}
Index: de/branches/objecthierarchy/src/orxonox/CameraHandler.h
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/CameraHandler.h	(revision 2072)
+++ 	(revision )
@@ -1,69 +1,0 @@
-/*
- *   ORXONOX - the hottest 3D action shooter ever to exist
- *                    > www.orxonox.net <
- *
- *
- *   License notice:
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License
- *   as published by the Free Software Foundation; either version 2
- *   of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- *   Author:
- *      Benjamin Knecht
- *   Co-authors:
- *      ...
- *
- */
-
- /**
- @file  CameraHandler.h
- @brief Handles the instances of Camera class
- @author Benjamin Knecht <beni_at_orxonox.net>
-  */
-
-#ifndef _Camera_Handler_H__
-#define _Camera_Handler_H__
-
-#include "OrxonoxPrereqs.h"
-
-#include <cassert>
-#include <list>
-#include <OgrePrerequisites.h>
-
-namespace orxonox
-{
-    class _OrxonoxExport CameraHandler
-    {
-        public:
-            CameraHandler(Ogre::Viewport* viewport);
-            ~CameraHandler();
-
-            Camera* getActiveCamera() const;
-
-            void requestFocus(Camera* camera);
-            void releaseFocus(Camera* camera);
-
-            static CameraHandler& getInstance() { assert(singletonRef_s); return *singletonRef_s; }
-
-        private:
-            CameraHandler(const CameraHandler&);
-
-            std::list<Camera*> cameraList_;
-            Ogre::Viewport* viewport_;
-
-            static CameraHandler* singletonRef_s;
-    };
-}
-
-#endif /* _Camera_Handler_H__ */
Index: /code/branches/objecthierarchy/src/orxonox/CameraManager.cc
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/CameraManager.cc	(revision 2073)
+++ /code/branches/objecthierarchy/src/orxonox/CameraManager.cc	(revision 2073)
@@ -0,0 +1,103 @@
+/*
+ *   ORXONOX - the hottest 3D action shooter ever to exist
+ *                    > www.orxonox.net <
+ *
+ *
+ *   License notice:
+ *
+ *   This program is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU General Public License
+ *   as published by the Free Software Foundation; either version 2
+ *   of the License, or (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the Free Software
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *
+ *   Author:
+ *      Benjamin Knecht
+ *   Co-authors:
+ *      Fabian 'x3n' Landau
+ *
+ */
+#include "OrxonoxStableHeaders.h"
+#include "CameraManager.h"
+
+#include <OgreViewport.h>
+
+#include "core/Core.h"
+#include "objects/worldentities/Camera.h"
+
+
+namespace orxonox
+{
+    CameraManager* CameraManager::singletonRef_s = 0;
+
+    CameraManager::CameraManager(Ogre::Viewport* viewport)
+        : viewport_(viewport)
+    {
+        assert(singletonRef_s == 0);
+        singletonRef_s = this;
+    }
+
+    CameraManager::~CameraManager()
+    {
+        assert(singletonRef_s != 0);
+        singletonRef_s = 0;
+    }
+
+    Camera* CameraManager::getActiveCamera() const
+    {
+        if (this->cameraList_.size() > 0)
+            return this->cameraList_.front();
+        else
+            return 0;
+    }
+
+    void CameraManager::requestFocus(Camera* camera)
+    {
+        if (!Core::showsGraphics())
+            return;
+
+        // notify old camera (if it exists)
+        if (this->cameraList_.size() > 0)
+            this->cameraList_.front()->removeFocus();
+
+        camera->setFocus(this->viewport_);
+
+        // add to list
+        std::list<Camera*>::iterator it;
+        for (it = this->cameraList_.begin(); it != this->cameraList_.end(); ++it)
+        {
+            if ((*it) == camera)
+                return; // make sure we don't add it twice
+        }
+        this->cameraList_.push_front(camera);
+    }
+
+    void CameraManager::releaseFocus(Camera* camera)
+    {
+        if (!Core::showsGraphics())
+            return;
+
+        // notify the cam of releasing the focus
+        if (this->cameraList_.front() == camera)
+        {
+            camera->removeFocus();
+            this->cameraList_.pop_front();
+
+            // set new focus if necessary
+            if (cameraList_.size() > 0)
+                cameraList_.front()->setFocus(this->viewport_);
+        }
+        else
+        {
+            this->cameraList_.remove(camera);
+        }
+    }
+}
Index: /code/branches/objecthierarchy/src/orxonox/CameraManager.h
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/CameraManager.h	(revision 2073)
+++ /code/branches/objecthierarchy/src/orxonox/CameraManager.h	(revision 2073)
@@ -0,0 +1,69 @@
+/*
+ *   ORXONOX - the hottest 3D action shooter ever to exist
+ *                    > www.orxonox.net <
+ *
+ *
+ *   License notice:
+ *
+ *   This program is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU General Public License
+ *   as published by the Free Software Foundation; either version 2
+ *   of the License, or (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the Free Software
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *
+ *   Author:
+ *      Benjamin Knecht
+ *   Co-authors:
+ *      Fabian 'x3n' Landau
+ *
+ */
+
+ /**
+ @file  CameraManager.h
+ @brief Handles the instances of Camera class
+ @author Benjamin Knecht <beni_at_orxonox.net>
+  */
+
+#ifndef _CameraManager_H__
+#define _CameraManager_H__
+
+#include "OrxonoxPrereqs.h"
+
+#include <cassert>
+#include <list>
+#include <OgrePrerequisites.h>
+
+namespace orxonox
+{
+    class _OrxonoxExport CameraManager
+    {
+        public:
+            CameraManager(Ogre::Viewport* viewport);
+            ~CameraManager();
+
+            Camera* getActiveCamera() const;
+
+            void requestFocus(Camera* camera);
+            void releaseFocus(Camera* camera);
+
+            static CameraManager& getInstance() { assert(singletonRef_s); return *singletonRef_s; }
+
+        private:
+            CameraManager(const CameraManager&);
+
+            std::list<Camera*> cameraList_;
+            Ogre::Viewport* viewport_;
+
+            static CameraManager* singletonRef_s;
+    };
+}
+
+#endif /* _CameraManager_H__ */
Index: /code/branches/objecthierarchy/src/orxonox/OrxonoxPrereqs.h
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/OrxonoxPrereqs.h	(revision 2072)
+++ /code/branches/objecthierarchy/src/orxonox/OrxonoxPrereqs.h	(revision 2073)
@@ -80,5 +80,5 @@
     class RadarListener;
 
-    class CameraHandler;
+    class CameraManager;
     class LevelManager;
 
@@ -107,4 +107,8 @@
     class Pawn;
     class SpaceShip;
+
+    class Trigger;
+    class DistanceTrigger;
+    class EventTrigger;
 
     class Controller;
Index: /code/branches/objecthierarchy/src/orxonox/gamestates/GSLevel.h
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/gamestates/GSLevel.h	(revision 2072)
+++ /code/branches/objecthierarchy/src/orxonox/gamestates/GSLevel.h	(revision 2073)
@@ -68,5 +68,5 @@
         Radar*                radar_;            //!< represents the Radar (not the HUD part)
         XMLFile*              startFile_;        //!< current hard coded default level
-        CameraHandler*        cameraHandler_;
+        CameraManager*        cameraManager_;
         LevelManager*         levelManager_;
 
Index: /code/branches/objecthierarchy/src/orxonox/objects/worldentities/Camera.cc
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/objects/worldentities/Camera.cc	(revision 2072)
+++ /code/branches/objecthierarchy/src/orxonox/objects/worldentities/Camera.cc	(revision 2073)
@@ -41,5 +41,5 @@
 #include "core/ConfigValueIncludes.h"
 #include "objects/Scene.h"
-#include "CameraHandler.h"
+#include "CameraManager.h"
 
 namespace orxonox
@@ -102,15 +102,15 @@
     void Camera::requestFocus()
     {
-        CameraHandler::getInstance().requestFocus(this);
+        CameraManager::getInstance().requestFocus(this);
     }
 
     void Camera::releaseFocus()
     {
-        CameraHandler::getInstance().releaseFocus(this);
+        CameraManager::getInstance().releaseFocus(this);
     }
 
     /**
         what to do when camera loses focus (do not request focus in this function!!)
-        this is called by the CameraHandler singleton class to notify the camera
+        this is called by the CameraManager singleton class to notify the camera
     */
     void Camera::removeFocus()
Index: /code/branches/objecthierarchy/src/orxonox/objects/worldentities/Camera.h
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/objects/worldentities/Camera.h	(revision 2072)
+++ /code/branches/objecthierarchy/src/orxonox/objects/worldentities/Camera.h	(revision 2073)
@@ -40,5 +40,5 @@
     class _OrxonoxExport Camera : public PositionableEntity, public Tickable
     {
-        friend class CameraHandler;
+        friend class CameraManager;
 
         public:

Index: /code/branches/objecthierarchy/src/orxonox/gamestates/GSLevel.cc
===================================================================
--- /code/branches/objecthierarchy/src/orxonox/gamestates/GSLevel.cc	(revision 2072)
+++ /code/branches/objecthierarchy/src/orxonox/gamestates/GSLevel.cc	(revision 2073)
@@ -44,5 +44,5 @@
 #include "objects/Radar.h"
 //#include "tools/ParticleInterface.h"
-#include "CameraHandler.h"
+#include "CameraManager.h"
 #include "LevelManager.h"
 #include "Settings.h"
@@ -57,5 +57,5 @@
         , radar_(0)
         , startFile_(0)
-        , cameraHandler_(0)
+        , cameraManager_(0)
         , levelManager_(0)
     {
@@ -82,7 +82,7 @@
             inputState_->setHandler(keyBinder_);
 
             // create the global CameraHandler
             assert(viewport);
-            this->cameraHandler_ = new CameraHandler(viewport);
+            this->cameraManager_ = new CameraManager(viewport);
 
             // Start the Radar
@@ -146,6 +146,6 @@
             delete this->radar_;
 
-        if (this->cameraHandler_)
-            delete this->cameraHandler_;
+        if (this->cameraManager_)
+            delete this->cameraManager_;
 
         if (this->levelManager_)
@@ -82,7 +82,7 @@
             inputState_->setHandler(keyBinder_);
 
-            // create the global CameraHandler
+            // create the global CameraManager
             assert(viewport);